Skip to contents

Guides the user to assign each argument required for a movement design workflow, including species label and key simulation settings. Users may choose to set a specific population sample size (number of animals tagged/to be tagged) or optimize the population sample size considering a specific analytical target.

Usage

md_configure(data, models = NULL, parallel = FALSE)

Arguments

data

A named list of simulated movement datasets, each a telemetry object compatible with ctmm R package. Each object must contain valid metadata and timestamped locations.

models

(Optional) Named list of fitted ctmm models (from ctmm::ctmm.fit() or ctmm::ctmm.select()). If not supplied, models are fitted automatically.

parallel

Logical. If TRUE, enables parallel processing.

Value

An object of class movedesign_input (and movedesign). This is a structured S3 list containing all validated inputs, model fits, and derived parameters for the study design workflow.

Details

The argument data is required and must be supplied directly (as a list of telemetry objects, obtained from ctmm::as.telemetry()). The argument models is optional, and if omitted, models will be fitted automatically.

See also

Examples

if(interactive()) {
  data(buffalo)
  md_params <- md_configure(data = buffalo)
}